==> nest-component-snowflake-3.5.3.0-20251216.064212-9-sources.jar: com/digiwin/dap/nest/component/snowflake/DwSnowflakeClusterAdapter.java <==
package com.digiwin.dap.nest.component.snowflake;

import com.digiwin.dap.nest.kernel.core.config.DwProperty;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.JaSnowflakeId;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.JaSnowflakeIdConfig;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.WorkerIdConfig;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.WorkerIdHandler;
import com.digiwin.dap.nest.kernel.meta.exception.DwException;

/**
 * 集群中各个instance自动分配自增序列, 以适配雪花的workId
 *
 * @author chenjian
 * @since 2025年12月16日 09:35:28
 */
public class DwSnowflakeClusterAdapter {

    private DwSnowflakeClusterAdapter() {
    }

    /**
     * 给个默认值
     * 防止workId没有初始化完成，mq消息已经进行消费了
     */
    private static WorkerIdHandler clusterWorkerIdHandler;

    private static Long workerId;

    public static WorkerIdHandler getClusterWorkerIdHandler() {
        return clusterWorkerIdHandler;
    }

    public static void setClusterWorkerIdHandler(WorkerIdHandler clusterWorkerIdHandler) {
        DwSnowflakeClusterAdapter.clusterWorkerIdHandler = clusterWorkerIdHandler;
    }

    public static Long getWorkerId() {
        return workerId;
    }

    public static void setWorkerId(Long workerId) {
        DwSnowflakeClusterAdapter.workerId = workerId;
    }

    public static void initClusterWorkerIdHandler() {
        Long workerIdBit = DwProperty.getLong(WorkerIdHandler.KeyBit, 3L);
        long maxWorkerId = (1L << workerIdBit) - 1;
        if (workerId > maxWorkerId) {
            throw new DwException(String.format(
                    "workerId %d exceeds max limit %d (workerIdBit=%d)",
                    workerId, maxWorkerId, workerIdBit));
        }
        clusterWorkerIdHandler = () -> WorkerIdConfig.builder()
                .workerId(workerId)
                .workerIdBit(DwProperty.getLong(WorkerIdHandler.KeyBit, 3L))
                .build();
    }

    public static JaSnowflakeId createDefault() {
        JaSnowflakeIdConfig orderIdConfig = new JaSnowflakeIdConfig();
        orderIdConfig.setBeginTimeStr("2025-11-07 20:43:30");
        orderIdConfig.setSequenceNumberBit(6);
        orderIdConfig.setTimeUnit(500);
        return JaSnowflakeId.newInstance(orderIdConfig, clusterWorkerIdHandler);
    }
}

==> nest-component-snowflake-5.5.0.1000-20251217.130154-8-sources.jar: com/digiwin/dap/nest/component/snowflake/DwSnowflakeClusterAdapter.java <==
package com.digiwin.dap.nest.component.snowflake;

import com.digiwin.dap.nest.kernel.core.config.DwProperty;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.DwSnowflakeId;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.DwSnowflakeIdConfig;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.WorkerIdConfig;
import com.digiwin.dap.nest.kernel.core.util.algorithm.id.snowflake.WorkerIdHandler;
import com.digiwin.dap.nest.kernel.meta.exception.DwException;

/**
 * 集群中各个instance自动分配自增序列, 以适配雪花的workId
 *
 * @author chenjian
 * @since 2025年12月16日 09:35:28
 */
public class DwSnowflakeClusterAdapter {

    private DwSnowflakeClusterAdapter() {
    }

    /**
     * 给个默认值
     * 防止workId没有初始化完成，mq消息已经进行消费了
     */
    private static WorkerIdHandler clusterWorkerIdHandler;

    private static Long workerId;

    public static WorkerIdHandler getClusterWorkerIdHandler() {
        return clusterWorkerIdHandler;
    }

    public static void setClusterWorkerIdHandler(WorkerIdHandler clusterWorkerIdHandler) {
        DwSnowflakeClusterAdapter.clusterWorkerIdHandler = clusterWorkerIdHandler;
    }

    public static Long getWorkerId() {
        return workerId;
    }

    public static void setWorkerId(Long workerId) {
        DwSnowflakeClusterAdapter.workerId = workerId;
    }

    public static void initClusterWorkerIdHandler() {
        Long workerIdBit = DwProperty.getLong(WorkerIdHandler.KeyBit, 3L);
        long maxWorkerId = (1L << workerIdBit) - 1;
        if (workerId > maxWorkerId) {
            throw new DwException(String.format(
                    "workerId %d exceeds max limit %d (workerIdBit=%d)",
                    workerId, maxWorkerId, workerIdBit));
        }
        clusterWorkerIdHandler = () -> WorkerIdConfig.builder()
                .workerId(workerId)
                .workerIdBit(DwProperty.getLong(WorkerIdHandler.KeyBit, 3L))
                .build();
    }

    public static DwSnowflakeId createDefault() {
        DwSnowflakeIdConfig orderIdConfig = new DwSnowflakeIdConfig();
        orderIdConfig.setBeginTimeStr("2025-11-07 20:43:30");
        orderIdConfig.setSequenceNumberBit(6);
        orderIdConfig.setTimeUnit(500);
        return DwSnowflakeId.newInstance(orderIdConfig, clusterWorkerIdHandler);
    }
}
